@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2016-10-28'; # DATE
-our $VERSION = '0.56'; # VERSION
+our $DATE = '2016-10-30'; # DATE
+our $VERSION = '0.57'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,6 +15,7 @@ our @EXPORT_OK = qw(
                        hashify_answer
                        arrayify_answer
                        combine_answers
+                       modify_answer
                        complete_array_elem
                        complete_hash_key
                        complete_comma_sep
@@ -208,7 +209,14 @@ sub complete_array_elem {
     my $char_mode   = $Complete::Common::OPT_CHAR_MODE;
     my $fuzzy       = $Complete::Common::OPT_FUZZY;
 
-    return [] unless @$array0;
+    $log->tracef("[computil] entering complete_array_elem(), word=<%s>", $word)
+        if $COMPLETE_UTIL_TRACE;
+
+    my $res;
+
+    unless (@$array0) {
+        $res = []; goto RETURN_RES;
+    }
 
     # normalize
     my $wordn = $ci ? uc($word) : $word; $wordn =~ s/_/-/g if $map_case;
@@ -393,7 +401,12 @@ sub complete_array_elem {
         }
     }
 
-    return $ci ? [sort {lc($a) cmp lc($b)} @words] : [sort @words];
+    $res =$ci ? [sort {lc($a) cmp lc($b)} @words] : [sort @words];
+
+  RETURN_RES:
+    $log->tracef("[computil] leaving complete_array_elem(), res=%s", $res)
+        if $COMPLETE_UTIL_TRACE;
+    $res;
 }
 
 $SPEC{complete_hash_key} = {
@@ -656,6 +669,42 @@ sub combine_answers {
     $encounter_hash ? $final : $final->{words};
 }
 
+$SPEC{modify_answer} = {
+    v => 1.1,
+    summary => 'Modify answer (add prefix/suffix, etc)',
+    args => {
+        answer => {
+            schema => ['any*', of=>['hash*','array*']], # XXX answer_t
+            req => 1,
+            pos => 0,
+        },
+        suffix => {
+            schema => 'str*',
+        },
+        prefix => {
+            schema => 'str*',
+        },
+    },
+    result_naked => 1,
+    result => {
+        schema => 'undef',
+    },
+};
+sub modify_answer {
+    my %args = @_;
+
+    my $answer = $args{answer};
+    my $words = ref($answer) eq 'HASH' ? $answer->{words} : $answer;
+
+    if (defined(my $prefix = $args{prefix})) {
+        $_ = "$prefix$_" for @$words;
+    }
+    if (defined(my $suffix = $args{suffix})) {
+        $_ = "$_$suffix" for @$words;
+    }
+    undef;
+}
+
 1;
 # ABSTRACT: General completion routine
 
@@ -671,7 +720,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.56 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-28.
+This document describes version 0.57 of Complete::Util (from Perl distribution Complete-Util), released on 2016-10-30.
 
 =head1 DESCRIPTION
 
@@ -913,6 +962,27 @@ Metadata (extra keys) for the hash.
 
 Return value:  (hash)
 
+
+=head2 modify_answer(%args) -> undef
+
+Modify answer (add prefix/suffix, etc).
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<answer>* => I<hash|array>
+
+=item * B<prefix> => I<str>
+
+=item * B<suffix> => I<str>
+
+=back
+
+Return value:  (undef)
+
 =head1 FAQ
 
 =head2 Why is fuzzy matching slow?
@@ -965,7 +1035,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Util>.
+Source repository is at L<https://github.com/sharyanto/perl-SHARYANTO-Complete-Util>.
 
 =head1 BUGS
 
